@@ -14,7 +14,7 @@
   
     You should have received a copy of the GNU General Public License
     along with mini18n; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifndef MINI18N_PV_LIST_H
@@ -27,7 +27,7 @@ typedef struct _mini18n_list_t mini18n_list_t;
 struct _mini18n_list_t {
 	char * key;
 	mini18n_data_t * data;
-	char * value;
+	void * value;
 	struct _mini18n_list_t * next;
 };
 
